# Workflow
- Run `mise run lint` to run linters after every edit.
- Run `mise run tests` to run the entire test suite.
- Run `mise run tests_all_versions` to run tests against all suported versions of Python. Only run this when explicitly dealing with differences in behavior between Python versions.